;;; -*- lisp -*-

;; ASDF system definition for loading the Swank server independently
;; of Emacs.
;;
;; This is only useful if you want to start a Swank server in a Lisp
;; processes that doesn't run under Emacs. Lisp processes created by
;; `M-x slime' automatically start the server.

;; Usage:
;;
;;   (require :swank)
;;   (swank:create-swank-server PORT) => ACTUAL-PORT
;;
;; (PORT can be zero to mean "any available port".)
;; Then the Swank server is running on localhost:ACTUAL-PORT. You can
;; use `M-x slime-connect' to connect Emacs to it.
;;
;; This code has been placed in the Public Domain.  All warranties
;; are disclaimed.

;; Debian change: swank-loader.lisp doesn't cope with
;; common-lisp-controller, because it expects to find the
;; swank-backend.lisp file in the same directory in which it is being
;; compiled.  So we let ASDF load the right backend and files.
;;
;; This list is extracted from swank-loader.lisp (see the definition
;; of *sysdep-pathnames*).  It must be kept in sync through the
;; releases.
;(asdf:defsystem :swank
;    :components ((:file "swank-loader")))
(asdf:defsystem :swank
    :name "swank"
    :serial t
    :components ((:file "swank-backend")
                 (:file "nregex")

		 #+cmu (:file "swank-source-path-parser")
		 #+cmu (:file "swank-source-file-cache")
		 #+cmu (:file "swank-cmucl")

		 #+sbcl (:file "swank-sbcl")
		 #+sbcl (:file "swank-source-path-parser")
		 #+sbcl (:file "swank-source-file-cache")
		 #+sbcl (:file "swank-gray")

		 #+openmcl (:file "metering")
		 #+openmcl (:file "swank-openmcl")
		 #+openmcl (:file "swank-gray")
		 
		 #+lispworks (:file "swank-lispworks")
		 #+lispworks (:file "swank-gray")

		 #+allegro (:file "swank-allegro")
		 #+allegro (:file "swank-gray")

		 #+clisp (:file "metering")
		 #+clisp (:file "swank-clisp")
		 #+clisp (:file "swank-gray")

		 #+armedbear (:file "swank-abcl")

		 #+cormanlisp (:file "swank-corman")
		 #+cormanlisp (:file "swank-gray")
		 
		 #+ecl (:file "swank-ecl")
		 #+ecl (:file "swank-gray")
		 (:file "swank")))
